

TODO_45_75_75_65 Merge `instance_data` into `envelop_payload`.

Instead of maintaining two data fields `instance_data` and `envelope_payload`, use `envelope_payload` only.

Remove `instance_data` and use `envelope_payload`:
data comes inside via plugins - they ensure `envelope_payload` is validated against `envelope_class`.

`envelope_class` should define what schema is used by `envelope_payload` and it should be extendable:
*   Core argrelay may rely on some of the fields inside `envelope_payload`.
*   Higher level plugin may rely on extended fields.
